@@ -1,6 +1,6 @@
 package Gearman::Util;
 use version;
-$Gearman::Util::VERSION = qv("1.130.003");
+$Gearman::Util::VERSION = qv("1.130.004");
 
 use strict;
 use warnings;
@@ -14,7 +14,7 @@ use IO::Handle;
 
 =head1 NAME
 
-Gearman::Util
+Gearman::Util - Utility functions for gearman distributed job system
 
 =head1 METHODS
 
